@@ -2,12 +2,12 @@
 
 __author__ = "eseunghwan"
 __email__ = "shlee0920@naver.com"
-__version__ = "0.5.0"
+__version__ = "0.5.1"
 
 from .core._vue import VueUtils as Vue
-from .core.server import Server
 from .webview import WebViewUtils as Webview
+from .core.server import Server
 
 __all__ = [
-    "Vue"
+    "Vue", "Webview", "Server"
 ]
